==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall.md <==
# AmazonRoute53ResolverDnsFirewall


```text
aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall
```

```text
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall')
```



| Illustration | AmazonRoute53ResolverDnsFirewall | AmazonRoute53ResolverDnsFirewallCard | AmazonRoute53ResolverDnsFirewallGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall.png) | ![illustration for AmazonRoute53ResolverDnsFirewall](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall.Local.png) | ![illustration for AmazonRoute53ResolverDnsFirewallCard](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewallCard.Local.png) | ![illustration for AmazonRoute53ResolverDnsFirewallGroup](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewallGroup.Local.png) |




## AmazonRoute53ResolverDnsFirewall

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRoute53ResolverDnsFirewall
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall')

' renders the element
AmazonRoute53ResolverDnsFirewall('AmazonRoute53ResolverDnsFirewall', 'Amazon Route53 Resolver Dns Firewall', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRoute53ResolverDnsFirewall
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall')

' renders the element
AmazonRoute53ResolverDnsFirewall('AmazonRoute53ResolverDnsFirewall', 'Amazon Route53 Resolver Dns Firewall', 'an optional tech label')
@enduml
```

## AmazonRoute53ResolverDnsFirewallCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRoute53ResolverDnsFirewallCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall')

' renders the element
AmazonRoute53ResolverDnsFirewallCard('AmazonRoute53ResolverDnsFirewallCard', 'Amazon Route53 Resolver Dns Firewall Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRoute53ResolverDnsFirewallCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall')

' renders the element
AmazonRoute53ResolverDnsFirewallCard('AmazonRoute53ResolverDnsFirewallCard', 'Amazon Route53 Resolver Dns Firewall Card', 'an optional description')
@enduml
```

## AmazonRoute53ResolverDnsFirewallGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRoute53ResolverDnsFirewallGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall')

' renders the element
AmazonRoute53ResolverDnsFirewallGroup('AmazonRoute53ResolverDnsFirewallGroup', 'Amazon Route53 Resolver Dns Firewall Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRoute53ResolverDnsFirewallGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall')

' renders the element
AmazonRoute53ResolverDnsFirewallGroup('AmazonRoute53ResolverDnsFirewallGroup', 'Amazon Route53 Resolver Dns Firewall Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall.md <==
# AmazonRoute53ResolverDnsFirewall


```text
aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall
```

```text
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall')
```



| Illustration | AmazonRoute53ResolverDnsFirewall | AmazonRoute53ResolverDnsFirewallCard | AmazonRoute53ResolverDnsFirewallGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall.png) | ![illustration for AmazonRoute53ResolverDnsFirewall](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall.Local.png) | ![illustration for AmazonRoute53ResolverDnsFirewallCard](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewallCard.Local.png) | ![illustration for AmazonRoute53ResolverDnsFirewallGroup](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewallGroup.Local.png) |




## AmazonRoute53ResolverDnsFirewall

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRoute53ResolverDnsFirewall
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall')

' renders the element
AmazonRoute53ResolverDnsFirewall('AmazonRoute53ResolverDnsFirewall', 'Amazon Route53 Resolver Dns Firewall', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRoute53ResolverDnsFirewall
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall')

' renders the element
AmazonRoute53ResolverDnsFirewall('AmazonRoute53ResolverDnsFirewall', 'Amazon Route53 Resolver Dns Firewall', 'an optional tech label')
@enduml
```

## AmazonRoute53ResolverDnsFirewallCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRoute53ResolverDnsFirewallCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall')

' renders the element
AmazonRoute53ResolverDnsFirewallCard('AmazonRoute53ResolverDnsFirewallCard', 'Amazon Route53 Resolver Dns Firewall Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRoute53ResolverDnsFirewallCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall')

' renders the element
AmazonRoute53ResolverDnsFirewallCard('AmazonRoute53ResolverDnsFirewallCard', 'Amazon Route53 Resolver Dns Firewall Card', 'an optional description')
@enduml
```

## AmazonRoute53ResolverDnsFirewallGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRoute53ResolverDnsFirewallGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall')

' renders the element
AmazonRoute53ResolverDnsFirewallGroup('AmazonRoute53ResolverDnsFirewallGroup', 'Amazon Route53 Resolver Dns Firewall Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRoute53ResolverDnsFirewallGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonRoute53ResolverDnsFirewall')

' renders the element
AmazonRoute53ResolverDnsFirewallGroup('AmazonRoute53ResolverDnsFirewallGroup', 'Amazon Route53 Resolver Dns Firewall Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
